local _, ns = ...
local SyLevel = ns.SyLevel

local colorTable = ns.colorTable

local frame = CreateFrame('Frame', nil, InterfaceOptionsFramePanelContainer)
frame:Hide()
frame.name = 'Filter: Item Level'
frame.parent = 'SyLevel'

frame:SetScript('OnShow', function(self)
	self:CreateOptions()
	self:SetScript('OnShow', nil)
end)

function frame:CreateOptions()
	local title = ns.createFontString(self, 'GameFontNormalLarge')
	title:SetPoint('TOPLEFT', 16, -16)
	title:SetText'SyLevel: Filter: Item Level'

	local thresLabel = ns.createFontString(self, 'GameFontNormalSmall')
	thresLabel:SetPoint('TOPLEFT', title, 'BOTTOMLEFT', 0, -16)
	--thresLabel:SetText('')
	
	local thesSlider = CreateFrame('Slider', 'SyLevelOptFSliderThreshold', self, 'OptionsSliderTemplate')
	thesSlider:SetPoint('TOPLEFT', thresLabel, 'BOTTOMLEFT', 0, 0)
	local function GetDBValue()
		return SyLevelDB.FilterSettings.ilevel
	end
	thesSlider:SetMinMaxValues(1, 645)
	thesSlider:SetOrientation("HORIZONTAL")
	thesSlider:SetValueStep(1)
	
	_G[thesSlider:GetName().."Low"]:SetText(1)
	_G[thesSlider:GetName().."High"]:SetText(645)
	_G[thesSlider:GetName().."Text"]:SetText("Minimum Item Level")
	
	local thesEditbox = CreateFrame('Editbox', 'SyLevelOptFEditboxThreshold', self)
	thesEditbox:SetPoint('TOP', thesSlider, 'BOTTOM',0,-6)
	thesEditbox:SetNumeric()
	thesEditbox:SetFontObject(ChatFontNormal)
	thesEditbox:SetMaxLetters(3)
	thesEditbox:SetJustifyH('CENTER')
	thesEditbox:SetHeight(20)
	thesEditbox:SetWidth(60)
	--[[thesEditbox:SetBackdrop( { 
		bgFile = "Interface\AddOns\SyUI\images\pixel", 
		edgeFile = "Interface\AddOns\SyUI\images\pixel", tile = false, tileSize = 0, edgeSize = 1.1, 
		insets = { left = 1, right = 1, top = 1, bottom = 1 }
	});
	thesEditbox:SetBackdropColor(0,0,0,0.5)
	thesEditbox:SetBackdropBorderColor(1,1,1,1)	]]--
	thesEditbox:SetAutoFocus(false)
	thesEditbox:SetScript('OnEscapePressed', function(self) self:ClearFocus() end)
	thesEditbox:SetScript('OnEditFocusGained', function(self)
		self:HighlightText(0, self:GetNumLetters())
	end)
	thesEditbox:SetScript('OnEditFocusLost', function(self)
		self:HighlightText(self:GetNumLetters())
	end)
	
	
	do -- After Variables Loaded?
		local UpdateSlider = function(self)
			local filters = SyLevelDB.FilterSettings
			local threshold = 1
			if(filters and filters.ilevel) then
				threshold = filters.ilevel
			end	
			thesSlider:SetValue(threshold)
		end
		
		local UpdateEditbox = function(self)
			local filters = SyLevelDB.FilterSettings
			local threshold = 1
			if(filters and filters.ilevel) then
				threshold = filters.ilevel
			end	
			thesEditbox:SetNumber(threshold)
		end
		
		thesSlider:SetScript("OnValueChanged",function(self,value)
			SyLevelDB.FilterSettings.ilevel = value
			SyLevel:CallOptionCallbacks()
			for pipe, active, name, desc in SyLevel.IteratePipes() do
				if(active) then
					SyLevel:UpdatePipe(pipe)
				end
			end
			UpdateEditbox()
		end)
		
		thesEditbox:SetScript("OnEnterPressed",function(self)
			local value = tonumber(self:GetText())
			if value then
				if value > 645 then
					value = 645
				elseif value < 1 then 
					value = 1 
				end
				SyLevelDB.FilterSettings.ilevel = value
				SyLevel:CallOptionCallbacks()
				for pipe, active, name, desc in SyLevel.IteratePipes() do
					if(active) then
						SyLevel:UpdatePipe(pipe)
					end
				end
				UpdateSlider()
				UpdateEditbox()
			end
			self:ClearFocus()
		end)		
	
		function frame:refresh()
			UpdateSlider()
			UpdateEditbox()
		end
		self:refresh()
	end
	--[[
	do
		local DropDown_OnClick = function(self)
			SyLevelDB.FilterSettings.ilevel = self.value - 1
			SyLevel:CallOptionCallbacks()

			for pipe, active, name, desc in SyLevel.IteratePipes() do
				if(active) then
					SyLevel:UpdatePipe(pipe)
				end
			end
			UIDropDownMenu_SetSelectedID(self:GetParent().dropdown, self:GetID())
		end

		local DropDown_OnEnter = function(self)
			GameTooltip:SetOwner(self, 'ANCHOR_TOPLEFT')
			GameTooltip:SetText('Controls the lowest item level that should be displayed.', nil, nil, nil, nil, 1)
		end

		local DropDown_OnLeave = GameTooltip_Hide

		local UpdateSelected = function(self)
			local filters = SyLevelDB.FilterSettings
			local threshold = 1
			if(filters and filters.ilevel) then
				threshold = filters.ilevel
			end

			UIDropDownMenu_SetSelectedID(thesDDown, threshold + 2)
		end

		local DropDown_init = function(self)
			local info

			for i=0,7 do
				info = UIDropDownMenu_CreateInfo()
				info.text = ns.Hex(colorTable[i]) .._G['ITEM_QUALITY' .. i .. '_DESC']
				info.value = i
				info.func = DropDown_OnClick

				UIDropDownMenu_AddButton(info)
			end
		end

		thesDDown:SetScript('OnEnter', DropDown_OnEnter)
		thesDDown:SetScript('OnLeave', DropDown_OnLeave)

		function frame:refresh()
			UIDropDownMenu_Initialize(thesDDown, DropDown_init)
			UpdateSelected()
		end
		self:refresh()
	end]]--
end

InterfaceOptions_AddCategory(frame)
